#!/bin/sh

###############################################################################
#
#   deviceTRUST VMware Horizon Installation Script, Version 23.1.400.0
#
#   Installs of uninstalls the deviceTRUST Client Extension for VMware Horizon.
#
#	To install:
#   	./horizon_install.sh INSTALL
#
#   To uninstall:
#       ./horizon_install.sh UNINSTALL
#
#   Copyright 2016-2023 deviceTRUST GmbH.
#
###############################################################################

# Define root VMware Horizon installation directory
HORIZON_ROOT=/usr/lib/vmware
RDPVCBRIDGE_DIR=${HORIZON_ROOT}/rdpvcbridge

# Directory that this script is located
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P )"

###############################################################################
#
# Functions
#
###############################################################################

#
# Header displays on all scenarios.
#
displayHeader() {
	echo "deviceTRUST VMware Horizon Installation Script, Version 23.1.400.0"
	echo
}

#
# Displays usage to the user
#
displayUsage() { 
	echo "Installs or uninstalls the deviceTRUST VMware Horizon Client."
	echo
	echo "Usage: $0 option"
	echo
	echo "Available options include:"
	echo
	echo "  INSTALL"
	echo
	echo "      Installs the deviceTRUST VMware Horizon Client."
	echo
	echo "  UNINSTALL"
	echo
	echo "      Uninstalls the deviceTRUST VMware Horizon Client."
	echo
}

#
# Installs the deviceTRUST VMware Horizon Client.
#
install() {
	
	echo "Creating VMware Horizon Virtual Channel at ${RDPVCBRIDGE_DIR}/libdtclient.so."
	echo

	mkdir -p "${RDPVCBRIDGE_DIR}"
	rm --force "${RDPVCBRIDGE_DIR}/libdtclient.so"
	ln --symbolic "${SCRIPT_DIR}/libdtclient_vmware.so" "${RDPVCBRIDGE_DIR}/libdtclient.so"
	chmod +x "${RDPVCBRIDGE_DIR}/libdtclient.so"

	echo "Done."
	echo
}

#
# Uninstalls the deviceTRUST VMware Horizon Client.
#
uninstall() { 

	echo "Removing VMware Horizon Virtual Channel at ${RDPVCBRIDGE_DIR}/libdtclient.so."
	echo
	rm --force "${RDPVCBRIDGE_DIR}/libdtclient.so"

	echo "Done."	
	echo
}

###############################################################################
#
# Argument processing
#
###############################################################################

displayHeader

case $1 in
	"INSTALL"|"install")
	install ;;
	"UNINSTALL"|"uninstall")
	uninstall ;;
	*)
	displayUsage ;;
esac
