#!/usr/bin/awk -f

###############################################################################
#
#   deviceTRUST ICA 'module.ini' Registration Script, Version 23.1.400.0
#
#   Adds or removes the deviceTRUST Client Extension from module.ini. This script
#   is executed as part of ica_install.sh and should not be invoked manually.
#
#   Copyright 2016-2023 deviceTRUST GmbH.
#
###############################################################################

#
# Initialisation.
#
# Note: register is passed through as either:
#
#  1 - to register deviceTRUST.
#  0 - to unregister deviceTRUST (default).
#
BEGIN {

  inDeviceTRUST = 0;
  inICA = 0;
  foundICA = 0;
}

#
# Search for [deviceTRUST] section.
# 
/^\[deviceTRUST\]/ {

  # Enter [deviceTRUST] section
  inDeviceTRUST = 1;

  # Remove from output
  next
}

#
# In [deviceTRUST] section.
# 
inDeviceTRUST == 1 {

  if ($0 ~ /^\[/) {
  
    # Exit [deviceTRUST] section
    inDeviceTRUST = 0;
    
  } else {
  
    # Remove from output regardless of (un)register.
    next
  }
}

#
# Search for [ICA 3.0] section.
#
/^\[ICA 3.0\]/ {

  inICA = 1;

  # Preserve in output
  print

  # Skip (avoids us catching this below)
  next
}

#
# In [ICA 3.0] section.
#
inICA == 1 {

  if ($0 ~ /^\[/) {

	if (register == 1) {
	
    	# Add [deviceTRUST] section
    	print("[deviceTRUST]")
    	print("DriverName=dtclient.dll")
    	print("")
	}

    # Exit [ICA 3.0] section.
    inICA = 0;

    # We've handled the [ICA 3.0] section - we don't need to error.
	foundICA = 1;

  } else if ($0 ~ /^VirtualDriver/) {

    # Remove deviceTRUST from VirtualDriver
    gsub (/([^a-zA-Z]*deviceTRUST)|(deviceTRUST[^a-zA-Z]*)/, "")

	if (register == 1) {
	
    	# Insert deviceTRUST in VirtualDriver and print
    	gsub (/$/, ", deviceTRUST")
    	print
    
    	# Add deviceTRUST = On
    	print("deviceTRUST = On");
    
    	# Skip since we've printed
    	next
	}
    
  } else if ($0 ~ /^deviceTRUST/) {

    # Remove existing deviceTRUST=On
    next
  }
}

#
# Default action
#
{ print }

#
# End script - check we processed the section.
#
END {

    # Fail - we didn't find the ICA section
	if (foundICA = 0) {
	    print "The [ICA 3.0] section was not found"
		exit 1
	}
}
