#!/bin/sh

###############################################################################
#
#   deviceTRUST RDP Installation Script, Version 23.1.400.0
#
#   Installs or uninstalls the deviceTRUST Client Extension for FreeRDP 2.
#
#	To install:
#   	./rdp_install.sh INSTALL
#
#   To uninstall:
#       ./rdp_install.sh UNINSTALL
#
#   Copyright 2016-2023 deviceTRUST GmbH.
#
###############################################################################

# Define root RDP installation directory
RDP_ROOT=/usr/lib/x86_64-linux-gnu/freerdp2

# Directory that this script is located
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P )"

###############################################################################
#
# Functions
#
###############################################################################

#
# Header displays on all scenarios.
#
displayHeader() {
	echo "deviceTRUST RDP Installation Script, Version 23.1.400.0"
	echo
}

#
# Displays usage to the user
#
displayUsage() { 
	echo "Installs or uninstalls the deviceTRUST RDP Client for FreeRDP 2."
	echo
	echo "Usage: $0 option"
	echo
	echo "Available options include:"
	echo
	echo "  INSTALL"
	echo
	echo "      Installs the deviceTRUST RDP Client."
	echo
	echo "  UNINSTALL"
	echo
	echo "      Uninstalls the deviceTRUST RDP Client."
	echo
}

#
# Installs the deviceTRUST RDP Client.
#
install() {
	
	echo "Creating FreeRDP 2 Virtual Channel at ${RDP_ROOT}/libdeviceTRUST-client.so."
	echo

	mkdir -p "${RDP_ROOT}"
	rm --force "${RDP_ROOT}/libdeviceTRUST-client.so"
	ln --symbolic "${SCRIPT_DIR}/libdtclient_rdp.so" "${RDP_ROOT}/libdeviceTRUST-client.so"

	echo "Done."
	echo
}

#
# Uninstalls the deviceTRUST RDP Client.
#
uninstall() { 

	echo "Removing FreeRDP 2 Virtual Channel at ${RDP_ROOT}/libdeviceTRUST-client.so."
	echo
	rm --force "${RDP_ROOT}/libdeviceTRUST-client.so"

	echo "Done."
	echo
}

###############################################################################
#
# Argument processing
#
###############################################################################

displayHeader

case $1 in
	"INSTALL"|"install")
	install ;;
	"UNINSTALL"|"uninstall")
	uninstall ;;
	*)
	displayUsage ;;
esac
