#!/bin/sh

###############################################################################
#
#   deviceTRUST Amazon WorkSpaces Installation Script, Version 23.1.400.0
#
#   Installs of uninstalls the deviceTRUST Client Extension for
#   Amazon WorkSpaces PCoIP.
#
#	To install:
#   	./workspaces_install.sh INSTALL
#
#   To uninstall:
#       ./workspaces_install.sh UNINSTALL
#
#   Copyright 2016-2023 deviceTRUST GmbH.
#
###############################################################################

# Define root PCoIP installation directory
PCOIP_ROOT=/usr/lib/x86_64-linux-gnu/pcoip-client/vchan_plugins
DCV_PLUGINS_DIR=/usr/share/dcvextensions/

# Directory that this script is located
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P )"

###############################################################################
#
# Functions
#
###############################################################################

#
# Header displays on all scenarios.
#
displayHeader() {
	echo "deviceTRUST Amazon WorkSpaces Installation Script, Version 23.1.400.0"
	echo
}

#
# Displays usage to the user
#
displayUsage() { 
	echo "Installs or uninstalls the deviceTRUST Amazon WorkSpaces Client."
	echo
	echo "Usage: $0 option"
	echo
	echo "Available options include:"
	echo
	echo "  INSTALL"
	echo
	echo "      Installs the deviceTRUST Amazon WorkSpaces Client."
	echo
	echo "  UNINSTALL"
	echo
	echo "      Uninstalls the deviceTRUST Amazon WorkSpaces Client."
	echo
}

#
# Installs the deviceTRUST Amazon WorkSpaces Client.
#
install() {
	
	echo "Registering DCV Extension at ${DCV_PLUGINS_DIR}/devicetrust-client-extension.json..."
    "${SCRIPT_DIR}/dcv" register "--file:${DCV_PLUGINS_DIR}/devicetrust-client-extension.json" --trace-console --trace-level:5
    echo

	echo "Creating Amazon WorkSpaces Virtual Channel at ${PCOIP_ROOT}/libpcoip_vchan_deviceTRUST.so."
	echo

	mkdir -p "${PCOIP_ROOT}"
	rm --force "${PCOIP_ROOT}/libpcoip_vchan_deviceTRUST.so"
	ln --symbolic "${SCRIPT_DIR}/libdtclient_pcoip.so" "${PCOIP_ROOT}/libpcoip_vchan_deviceTRUST.so"

	echo "Done."
	echo
}

#
# Uninstalls the deviceTRUST Amazon WorkSpaces Client.
#
uninstall() { 

    echo "Unregistering DCV Extension at ${DCV_PLUGINS_DIR}/devicetrust-client-extension.json..."
    echo
    rm -fv "${DCV_PLUGINS_DIR}/devicetrust-client-extension.json"

	echo "Removing Amazon WorkSpaces Virtual Channel at ${PCOIP_ROOT}/libpcoip_vchan_deviceTRUST.so."
	echo
	rm --force "${PCOIP_ROOT}/libpcoip_vchan_deviceTRUST.so"

	echo "Done."	
	echo
}

###############################################################################
#
# Argument processing
#
###############################################################################

displayHeader

case $1 in
	"INSTALL"|"install")
	install ;;
	"UNINSTALL"|"uninstall")
	uninstall ;;
	*)
	displayUsage ;;
esac
